FileFormatter class final
Default formatter for file log entries.
Creates log entries in a pipe-separated table format:
| [2023-06-15 12:34:56.789] | [INFO ] | This is a log message
ERROR and CRITICAL entries are wrapped in separator lines. Stack traces are indented and truncated at 1000 chars.
Implement LogFormatter to create custom formatters.
Constructors
- FileFormatter({DateFormat? dateFormat})
- Creates a file formatter.
Properties
- dateFormat → DateFormat
-
Date formatter for timestamps.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
FlexLog log) → String - Formats a log entry into a string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited